@@ -10,18 +10,8 @@
 # This program launched a text interface for creating OPTS configuration files. 
 # It has not been updated after a lot of changes to OPTS, so it is currently not usable.
 
-##############################################################################
-##############################################################################
-##############################################################################
-# HERE FOLLOWS THE CONTENT OF THE "opts_prepare.pl" FILE, WHICH HAS BEEN MERGED HERE
-# TO AVOID COMPLICATIONS WITH THE PERL MODULE INSTALLATION
-
-# This program launched a text interface for creating OPTS configuration files. 
-# It has not been updated after a lot of changes to OPTS, so it is currently not usable.
-
 no strict; 
 no warnings;
-use lib "../../";
 
 sub prepare 
 { 
@@ -1218,13 +1208,13 @@ sub keep_obstructions_back ##THIS HAS TO BE REMADE TO BE SIMPLER AND NEATER: TAK
 	my $obstructionsdata   = $_[3];
 	my $obstructionsnumberprovv =
 	  scalar( @{ $$keep_obstructions[ $casenumber - 1 ][1] } );
-	if ( $obstructionsnumber eq "" )
+	if ( $obstructionsnumber == null )
 	{
 		$obstructionsnumber = "$obstructionsnumberprovv";
 	}
 	my $obstructionsdataprovv =
 	  Dumper( @{ $$keep_obstructions[ $casenumber - 1 ][1] } );
-	if ( $obstructionsdata eq "" )
+	if ( $obstructionsdata == null )
 	{
 		$obstructionsdata = "$obstructionsdataprovv";
 	}
@@ -1899,11 +1889,6 @@ my $printconstruction_reassignment = Dumper($construction_reassignment);
 mainloop(); 
 }
 
-# END OF THE CONTENT OF THE "opts_prepare.pl" FILE.
-##############################################################################
-##############################################################################
-##############################################################################
-
 
 1;
 
